#!/bin/bash

SAMPLES_DIR=../../../Samples/cut/
MODEL_DIR=../../../Model/cut/final

OPLOT=~/diss/sw/plot/oplot.py

function plot_trends() {
    ALGS=$1
    SRC="${MODEL_DIR}/${ALGS}/"

    echo "Plotting trends $SRC -> $ALGS/"

    $OPLOT -p "$ALGS/" ${SRC}/otrend*.csv
    rm $ALGS/*-RM_*RELEASE-LATENCY_*.pdf
}

function plot_ticks() {
    $OPLOT -p  event-driven/ -i 0 -x  7 -y 100000 ${SAMPLES_DIR}/event-driven/*overhead=TICK.sbn

    $OPLOT -p pfair-aligned/ -i 0 -x 30 -y 120000 \
	${SAMPLES_DIR}/pfair-aligned/*scheduler=*{L2,L3}*_*overhead=TICK.sbn
    $OPLOT -p pfair-aligned/ -i 0 -x 130 -b 2 -y 400000  \
	${SAMPLES_DIR}/pfair-aligned/*scheduler={PD2,PD2-RM}_*overhead=TICK.sbn

    $OPLOT -p pfair-staggered/ -i 0 -x 15 -y 600000 ${SAMPLES_DIR}/pfair-staggered/*overhead=TICK.sbn
}

function plot_release() {
    $OPLOT  -p event-driven/  \
	-i 0 -y 25000 -x 280 -b 4 \
	${SAMPLES_DIR}/event-driven/*scheduler=G-*_*overhead=RELEASE.sbn
    $OPLOT  -p event-driven/  \
	-i 0 -y 45000 -x 60 -b 1  \
	${SAMPLES_DIR}/event-driven/*scheduler={P,C}-*_*overhead=RELEASE.sbn

    $OPLOT -p pfair-aligned/ -i 0 -x 9 -y 70000 \
	${SAMPLES_DIR}/pfair-aligned/*overhead=RELEASE.sbn

    $OPLOT -p pfair-staggered/ -i 0 -x 9 -y 70000 \
	${SAMPLES_DIR}/pfair-staggered/*overhead=RELEASE.sbn
}


function plot_sched() {
    # manual filtering for SCHED
    $OPLOT -o ${SAMPLES_DIR}/event-driven/sched-outliers.csv -p event-driven/  \
	-i 0 -y 140000 -x 280 -b 4 \
	${SAMPLES_DIR}/event-driven/*scheduler=G-*_*overhead=SCHED.sbn
    $OPLOT -o ${SAMPLES_DIR}/event-driven/sched-outliers.csv -p event-driven/  \
	-i 0 -y 160000 -x 45 -b 1  \
	${SAMPLES_DIR}/event-driven/*scheduler={P,C}-*_*overhead=SCHED.sbn


    $OPLOT -o ${SAMPLES_DIR}/pfair-aligned/sched-outliers.csv -p pfair-aligned/  \
	-i 0 -x 130 -y 100000 -b 2 \
	${SAMPLES_DIR}/pfair-aligned/*scheduler={PD2,PD2-RM}_**overhead=SCHED.sbn
    $OPLOT -o ${SAMPLES_DIR}/pfair-aligned/sched-outliers.csv -p pfair-aligned/  \
	-i 0 -x 30 -y 30000  \
	${SAMPLES_DIR}/pfair-aligned/*scheduler=*{L2,L3}*_**overhead=SCHED.sbn

    $OPLOT -o ${SAMPLES_DIR}/pfair-staggered/sched-outliers.csv -p pfair-staggered/  \
	-i 0 -x 15 -y 140000 \
	${SAMPLES_DIR}/pfair-staggered/*overhead=SCHED.sbn
}

function plot_samples() {
    ALGS=$1
    SRC="${SAMPLES_DIR}/${ALGS}/"

    echo "Plotting samples $SRC -> $ALGS/"

    # no filtering for SCHED2, RELEASE, and TICK
    $OPLOT -p "$ALGS/" -i 0 -x 15 -y 120000 ${SRC}/*overhead=SCHED2.sbn

    # IQR with extent=12 for CXS, RELEASE-LATENCY, and SEND-RESCHEd
    $OPLOT -p "$ALGS/" -i 12 -x 15 -y 70000 ${SRC}/*overhead=CXS.sbn
    $OPLOT -p "$ALGS/" -i 12 -x 15 -y 40000 ${SRC}/*overhead=RELEASE-LATENCY.sbn
    $OPLOT -p "$ALGS/" -i 12 -x 15 -y 90000 ${SRC}/*overhead=SEND-RESCHED.sbn

    # remove noise
    rm -f $ALGS/*-RM_*RELEASE-LATENCY.pdf
}

plot_trends event-driven
plot_trends pfair-aligned
plot_trends pfair-staggered

plot_samples event-driven
plot_samples pfair-aligned
plot_samples pfair-staggered

plot_ticks
plot_sched
plot_release
